.. include:: ../README.rst
  :end-before: header

=======
Content
=======

.. toctree::
   :maxdepth: 2

   introduction.rst
   publishers.rst
   subscribers.rst
   operators.rst
   subjects.rst
   hub.rst

.. include:: ../README.rst
  :start-after: header
  :end-before: api